AxumNamedRouter
This is a router that wraps the Router from axum
and automatically adds an Extension<Routes> layer.
Check out NamedRouter and Routes for more information on how this works
Structs
- Named
Router - Wraps the axum
Routerwith an implementation that builds a mapping of route names to paths. - Routes
- A mapping of all route names to their paths.
This can be used in requests as it implements
FromRequestIt is also based on anArcinternally so it can be cloned across requests efficiently.